from django.conf import settings
from Crypto.PublicKey import RSA
from fastutils import rsautils


DEFAULT_DJANGO_SECURE_PASSWORD_INPUT_ENCRYPTED_VALUE_PREFIX = "rsa-encrypted:"
DEFAULT_DJANGO_SECURE_PASSWORD_INPUT_RSA_PRIVATE_KEY = """-----BEGIN RSA PRIVATE KEY-----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==
-----END RSA PRIVATE KEY-----
"""

encrypted_value_prefix = getattr(settings, "DJANGO_SECURE_PASSWORD_INPUT_ENCRYPTED_VALUE_PREFIX", DEFAULT_DJANGO_SECURE_PASSWORD_INPUT_ENCRYPTED_VALUE_PREFIX)
private_key_text = getattr(settings, "DJANGO_SECURE_PASSWORD_INPUT_RSA_PRIVATE_KEY", DEFAULT_DJANGO_SECURE_PASSWORD_INPUT_RSA_PRIVATE_KEY)
private_key = rsautils.load_private_key(private_key_text)
public_key = rsautils.load_public_key_from_private_key(private_key_text)
public_key_text = RSA.import_key(private_key_text).publickey().export_key().decode()
